Support for implementing transport layer protocols
The transport module provides the ability to send and receive packets at the transport layer using IPv4 or IPv6. It also enables layer 3 networking for specific transport protocols, using IPv4 only.
Note that this is limited by operating system support - for example, on OS X and FreeBSD, it is impossible to implement protocols which are already implemented in the kernel such as TCP and UDP.
Macros
- transport_
channel_ iterator - Create an iterator for some packet type.
Structs
- Config
- Structure used for holding all configurable options for describing possible options for transport channels.
- Icmp
Transport Channel Iterator - An iterator over packets of type
IcmpPacket. - Icmpv6
Transport Channel Iterator - An iterator over packets of type
Icmpv6Packet. - Ipv4
Transport Channel Iterator - An iterator over packets of type
Ipv4Packet. - TcpTransport
Channel Iterator - An iterator over packets of type
TcpPacket. - Transport
Receiver - Structure used for receiving at the transport layer. Should be created with
transport_channel(). - Transport
Sender - Structure used for sending at the transport layer. Should be created with
transport_channel(). - UdpTransport
Channel Iterator - An iterator over packets of type
UdpPacket.
Enums
- Ecn
- Transport
Channel Type - Type of transport channel to present.
- Transport
Protocol - Represents a transport layer protocol.
Functions
- icmp_
packet_ iter - Return a packet iterator with packets of type
IcmpPacketfor some transport receiver. - icmpv6_
packet_ iter - Return a packet iterator with packets of type
Icmpv6Packetfor some transport receiver. - ipv4_
packet_ iter - Return a packet iterator with packets of type
Ipv4Packetfor some transport receiver. - tcp_
packet_ iter - Return a packet iterator with packets of type
TcpPacketfor some transport receiver. - transport_
channel - Create a new
(TransportSender, TransportReceiver)pair. - transport_
channel_ with - Create a new
(TransportSender, TransportReceiver)pair using the additional options specified. - udp_
packet_ iter - Return a packet iterator with packets of type
UdpPacketfor some transport receiver.